# Unit Test Report: timerset

## SCENARIO 1: 2 timer sets, ts-1: timer-1 called twice, timer-2 called in between; ts-2: timer-1 called twice, initTime called in between; all outputs; mocked : 0 failed of 8: SUCCESS

## SCENARIO 2: As scenario 1 but not mocked, and with SELFs : 0 failed of 8: SUCCESS

## SCENARIO 3: Large numbers, mocked : 0 failed of 8: SUCCESS

## SCENARIO 4: Small numbers, mocked : 0 failed of 8: SUCCESS

## SCENARIO 5: Non-default DP, mocked : 0 failed of 8: SUCCESS

## SCENARIO 6: Zero DP, mocked : 0 failed of 8: SUCCESS

## SCENARIO 7: Error DP, mocked : 0 failed of 8: SUCCESS

# Test scenarios: 0 failed of 7: SUCCESS